@@ -3,4 +3,4 @@ from .model import SimpleVF
 from .model import CustomLoader
 from .eo_model import OdeNetEo
 
-__all__ = ["OdeNet", "OdeNetEo", "SimpleVF", "CustomLoader"]
+__all__ = ["OdeNet", "OdeNetEo", "SimpleVF", "CustomLoader", "ModelRegistry"]
